package org.dataglot.words;

import java.util.ArrayList;

public class Words
{
	private Words(final ArrayList<Word> wordList)
	{
		this.wordList = wordList;
	}

	private Words(final String... strings)
	{
		wordList = new ArrayList<Word>(strings.length);
		for (final String string : strings)
		{
			wordList.add(new Word(string));
		}
	}

	public WordsSpacing camel()
	{
		return new WordsSpacingCamel(wordList);
	}

	public WordsSpacing delimited(final String delim)
	{
		return new WordsSpacingIdentifier(wordList, delim);
	}

	public WordsSpacing human()
	{
		return human(" ");
	}

	public WordsSpacing human(final String delim)
	{
		return new WordsSpacingHuman(wordList, delim);
	}

	public WordsSpacing hyphen()
	{
		return delimited("-");
	}

	public Words plural()
	{
		final ArrayList<Word> newWordList = new ArrayList<Word>(wordList.size());
		for (int i = 0; i < wordList.size(); ++i)
		{
			if (i == wordList.size() - 1)
			{
				newWordList.add(i, wordList.get(i).plural());
			}
			else
			{
				newWordList.add(i, wordList.get(i));
			}
		}
		return new Words(newWordList);
	}

	public WordsSpacing underscore()
	{
		return delimited("_");
	}

	public static Words fromCamel(final String camelString)
	{
		final String[] strings = camelString.split("(?<!^)(?=[A-Z])");
		final ArrayList<Word> wordList = new ArrayList<Word>(strings.length);
		for (final String string : strings)
		{
			wordList.add(new Word(string.toLowerCase()));
		}
		return new Words(wordList);
	}

	public static Words fromStrings(final String... strings)
	{
		return new Words(strings);
	}

	private final ArrayList<Word> wordList;
}
